@@ -1,9 +1,8 @@
 #! /usr/bin/env python
 """
-A script for fitting the amplitudes and passbands of antennas given
-starting parameters in "a.loc" and a list of sources (from "a.src").
-
-Author: Aaron Parsons
+A script for fitting parameters of a measurement equation given 
+starting parameters in a cal file and a list of sources.  The fitter used
+here is a steepest-decent filter and does not make use of priors.
 """
 
 import aipy as a, numpy as n, sys, os, optparse
@@ -12,19 +11,11 @@ o = optparse.OptionParser()
 o.set_usage('fitmdl.py [options] *.uv')
 o.set_description(__doc__)
 a.scripting.add_standard_options(o, ant=True, pol=True, chan=True,
-    loc=True, src=True, dec=True)
+    cal=True, src=True, dec=True, prms=True)
+o.add_option('-S', '--shared_prms', dest='shprms',
+    help='Parameter listing w/ same syntax as "-P/--prms" except that all objects listed for a parameter will share an instance of that parameter.')
 o.add_option('--snap', dest='snap', action='store_true',
     help='Snapshot mode.  Fits parameters separately for each integration.')
-o.add_option('--fitants', dest='fitants', default='all',
-    help='Comma delimited list of antennas to fit. Default "all".')
-o.add_option('--aprms', dest='aprms',
-    help='Comma delimited list of paramters to fit independently for each antenna.')
-o.add_option('--shprms', dest='shprms',
-    help='Comma delimited list of parameters to fit whose values will be shared for all antennas.')
-o.add_option('--sprms', dest='sprms', 
-    help='Source=param pairs for fitting source parameters.')
-o.add_option('--aaprms', dest='aaprms',
-    help='Comma delimited list of AntennaArray (not Antenna) parameters to fit.  Unless added specifically in loc file, default AntennaArray has no parameters to fit.')
 o.add_option('-q', '--quiet', dest='quiet', action='store_true',
     help='Be less verbose.')
 o.add_option('--maxiter', dest='maxiter', type='float', default=-1,
@@ -42,44 +33,48 @@ opts, args = o.parse_args(sys.argv[1:])
 uv = a.miriad.UV(args[0])
 opts.ant += ',cross'
 a.scripting.uv_selector(uv, opts.ant, opts.pol)
-aa = a.loc.get_aa(opts.loc, uv['sdf'], uv['sfreq'], uv['nchan'])
+aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
 chans = a.scripting.parse_chans(opts.chan, uv['nchan'])
 aa.select_chans(chans)
 srclist,cutoff = a.scripting.parse_srcs(opts.src)
-cat = a.loc.get_catalog(opts.loc, srclist, cutoff)
+cat = a.cal.get_catalog(opts.cal, srclist, cutoff)
 (uvw,t,(i,j)),d = uv.read()
 aa.set_jultime(t)
 cat.compute(aa)
-if opts.fitants.startswith('all'): fitants = range(uv['nants'])
-else: fitants = map(int, opts.fitants.split(','))
 del(uv)
 if opts.maxiter < 0: opts.maxiter = n.Inf
 
-# Generate list of parameters to fit
-if opts.aprms is None: aprms = []
-else: aprms = opts.aprms.split(',')
-if opts.shprms is None: shprms = []
-else: shprms = opts.shprms.split(',')
-if opts.aaprms is None: aaprms = []
-else: aaprms = opts.aaprms.split(',')
-prm_dict = {}
-for ant in fitants: prm_dict[ant] = aprms[:]
-prm_dict[fitants[0]].extend(shprms)
-prm_dict['aa'] = aaprms
-#print prm_dict
+# Figure out parameters to fit
+prms, prm_dict, shkeys = {}, {}, []
+# Handle shared parameters
+if opts.shprms:
+    shprms = map(a.scripting.parse_prms, opts.shprms.split(','))
+    for s in shprms:
+        keys = s.keys(); keys.sort()
+        k = keys[0]
+        # Only enter one instance of shared parameters (indexed under first key)
+        if prms.has_key(k): prms[k].update(s[k])
+        else: prms.update({k:s[k]})
+        # Add an entry to shkeys for propagating variables to other objects
+        shkeys.append((keys, s[k].keys()))
+# Handle normal parameters
+if opts.prms:
+    pd = a.scripting.parse_prms(opts.prms)
+    for k in pd:
+        if prms.has_key(k): prms[k].update(pd[k])
+        else: prms[k] = pd[k]
+for prm in prms: prm_dict[prm] = prms[prm].keys()
 start_prms = aa.get_params(prm_dict)
-if opts.sprms != None:
-    sprms = [w.split('=') for w in opts.sprms.split(',')]
-    sprm_dict = {}
-    for src,prm in sprms:
-        if sprm_dict.has_key(src): sprm_dict[src].append(prm)
-        else: sprm_dict[src] = [prm]
-    start_prms.update(cat.get_params(sprm_dict))
-else: sprms = []
+start_prms.update(cat.get_params(prm_dict))
+for obj in start_prms:
+    for prm in start_prms[obj]:
+        if prms[obj][prm][0] != None:
+            start_prms[obj][prm] = prms[obj][prm][0]
+        
 prm_list, key_list = a.fit.flatten_prms(start_prms)
 
 first_fit = None    # Used to normalize fit values to the starting fit
-mfq = cat.get_mfreqs()
+mfq = cat.get('mfreq')
 dbuf = None
 
 # The function to be optimized
@@ -87,13 +82,17 @@ def fit_func(prms, filelist, decimate, decphs):
     global first_fit, dbuf
     if first_fit == 0: return 0
     prms = a.fit.reconstruct_prms(prms, key_list)
+    # Propagate shared params
+    for (skey,sprm) in shkeys:
+        k = skey[0]
+        for k2 in skey[1:]:
+            if not prms.has_key(k2): prms[k2] = {}
+            for sp in sprm:
+                prms[k2][sp] = prms[k][sp]
     if not opts.quiet: a.fit.print_params(prms)
-    for ant in fitants:
-        for prm in shprms:
-            prms[ant][prm] = prms[fitants[0]][prm]
     aa.set_params(prms)
     cat.set_params(prms)
-    a1,a2,th = cat.get_srcshapes()
+    a1,a2,th = cat.get('srcshape')
     score,nsamples = 0.,0.
     # Cache data from file to avoid hitting disk excessively
     if dbuf is None:
@@ -115,10 +114,9 @@ def fit_func(prms, filelist, decimate, decphs):
         aa.set_jultime(t)
         cat.compute(aa)
         eqs = cat.get_crds('eq', ncrd=3)
-        flx = cat.get_fluxes()
-        ind = cat.get_indices()
-        dra,ddec = cat.get_ionrefs()
-        aa.sim_cache(eqs, flx, indices=ind, mfreqs=mfq, 
+        flx = cat.get_jys()
+        dra,ddec = cat.get('ionref')
+        aa.sim_cache(eqs, flx, mfreqs=mfq, 
             ionrefs=(dra,ddec), srcshapes=(a1,a2,th))
         for bl in dbuf[t]:
             i,j = a.miriad.bl2ij(bl)
