@@ -12,7 +12,7 @@ import aipy as a, numpy as n, pylab as p, os, sys, optparse, pickle
 o = optparse.OptionParser()
 o.set_usage('flux_cal.py [options] *.uv')
 o.set_description(__doc__)
-a.scripting.add_standard_options(o, src=True, loc=True)
+a.scripting.add_standard_options(o, src=True, cal=True)
 o.add_option('-b', '--beam', dest='beam', action='store_true',
     help='Normalize by the primary beam response in the direction of the specified source.')
 o.add_option('-p', '--passband', dest='passband', action='store_true',
@@ -23,18 +23,18 @@ opts, args = o.parse_args(sys.argv[1:])
 
 assert(not (opts.src is None and (opts.beam or opts.srcflux)))
 uv = a.miriad.UV(args[0])
-freqs = a.loc.get_freqs(uv['sdf'], uv['sfreq'], uv['nchan'])
-aa = a.loc.get_aa(opts.loc, uv['sdf'], uv['sfreq'], uv['nchan'])
+freqs = a.cal.get_freqs(uv['sdf'], uv['sfreq'], uv['nchan'])
+aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
 del(uv)
 
 if opts.srcflux:
     srclist,cutoff = a.scripting.parse_srcs(opts.src)
-    src = a.loc.get_catalog(opts.loc, srclist, cutoff)
-    s = src.values()[0]
+    cat = a.cal.get_catalog(opts.cal, srclist, cutoff)
+    s = cat.values()[0]
     print 'Calibrating for source with',
-    print 'strength', s._janskies,
+    print 'strength', s._jys,
     print 'measured at', s.mfreq, 'GHz',
-    print 'with index', s._index
+    print 'with index', s.index
     src_spec = None
 else: src_spec = 1
 
@@ -47,9 +47,9 @@ def mfunc(uv, p, d, f):
         curtime = t
         aa.set_jultime(t)
         if opts.srcflux:
-            src.compute(aa)
-            src_spec = src.get_fluxes()
-            s_eq = src.get_crds('eq', ncrd=3)
+            s.compute(aa)
+            src_spec = s.get_jys()
+            s_eq = cat.get_crds('eq', ncrd=3)
             aa.sim_cache(s_eq)
     if i == j: return p, d, f
     if opts.passband: passband = aa.passband(i,j)
@@ -65,8 +65,8 @@ if opts.passband: ext += 'p'
 if opts.beam: ext += 'b'
 if opts.srcflux: ext += 'f'
 for filename in args:
-    print filename
     uvofile = filename + ext
+    print filename,'->',uvofile
     if os.path.exists(uvofile):
         print 'File exists: skipping'
         continue
