@@ -63,7 +63,7 @@ except(ImportError):
 o = optparse.OptionParser()
 o.set_usage('plot_map.py [options] mapfile')
 o.set_description(__doc__)
-a.scripting.add_standard_options(o, cmap=True, max=True, drng=True)
+a.scripting.add_standard_options(o, src=True, cmap=True, max=True, drng=True)
 o.add_option('-p', '--projection', dest='projection', default='moll',
     help='Map projection to use: moll (default), mill, cyl, robin, sinu.')
 o.add_option('-m', '--mode', dest='mode', default='log',
@@ -72,12 +72,12 @@ o.add_option('-c', '--cen', dest='cen', type='float',
     help="Center longitude/right ascension (in degrees) of map.  Default is 0 for galactic coordinate output, 180 for equatorial.")
 o.add_option('-j', '--juldate', dest='juldate', type='float', 
     help='Julian date used for locating moving sources.')
-o.add_option('--srcs', dest='srcs', type='float', default=1,
-    help="Cutoff flux (Jy) for labeling known radio sources in plot.  Default 1 Jy.")
 o.add_option('--src_mark', dest='src_mark', default='',
     help='Marker to put on src locations.  Can be: ".,o,+,x,^,v".  Default no marker.')
 o.add_option('--src_color', dest='src_color', default='k',
     help='Color of source label.  Can be: "k,w,r,b".  Default "k".')
+o.add_option('-o', '--outfile', dest='outfile', default='',
+    help='If provided, will save the figure to the specified file instead of popping up a window.')
 o.add_option('--isys', dest='isys', default='eq',
     help='Input coordinate system (in map).  Can be eq (equatorial, default), ga (galactic), or ec (ecliptic).')
 o.add_option('--osys', dest='osys', default='eq',
@@ -92,6 +92,8 @@ o.add_option('--res', dest='res', type='float', default=0.25,
     help="Resolution of plot (in degrees).  Default 0.25.")
 o.add_option('--nside', dest='nside', type='int',
     help="Manually set NSIDE (possibly degrading map) to a power of 2.")
+o.add_option('--mask', dest='mask', type='float',
+    help="Optional dB of weight below which data will be masked. Recommended=30")
 opts,args = o.parse_args(sys.argv[1:])
 
 cmap = p.get_cmap(opts.cmap)
@@ -126,11 +128,22 @@ m = a.coord.convert_m(opts.osys, opts.isys,
 x,y,z = n.dot(m, crd)
 try: data, indices = h[x,y,z]
 except(ValueError): data = h[x,y,z]
+if not opts.mask is None:
+    try:
+        wgts = h.wgt[x,y,z]
+        threshold = 10**(-opts.mask/10.)*n.max(wgts)
+        msk = n.where(wgts > threshold, 1, 0)
+        data *= msk
+        print "Masking %2.0f%% of sky"% ((1 - msk.sum() / float(len(msk)))*100)
+    except(AttributeError):
+        print "Weights not included in file. No mask will be applied."
 data.shape = lats.shape
 
+
 # Generate source locations
-if not opts.srcs is None:
-    cat = a.src.get_catalog(cutoff=opts.srcs)
+if not opts.src is None:
+    srclist,cutoff = a.scripting.parse_srcs(opts.src)
+    cat = a.src.get_catalog(srcs=srclist, cutoff=cutoff)
     o = ephem.Observer()
     if opts.juldate is None:
         o.date = ephem.J2000
@@ -138,12 +151,17 @@ if not opts.srcs is None:
         try: del(cat['Sun'])
         except(KeyError): pass
     else:
-        o.date = a.ant.juldate2ephem(opts.juldate)
+        o.date = a.phs.juldate2ephem(opts.juldate)
         o.epoch = o.date
-    cat.compute(o)
+    for s in cat.values():
+        try: a.phs.RadioFixedBody.compute(s, o)
+        except(TypeError): a.phs.RadioSpecial.compute(s, o)
+    #cat.compute(o)
     # lat/lon coordinates of sources
     scrds = [ephem.Equatorial(s.ra,s.dec,epoch=o.epoch) for s in cat.values()]
-    sflxs = cat.get_fluxes()
+    afreqs = n.array([.150])
+    cat.update_jys(afreqs)
+    sflxs = cat.get_jys().squeeze()
     snams = cat.keys()
     if opts.osys == 'ga':
         scrds = [ephem.Galactic(s, epoch=opts.oepoch) for s in scrds]
@@ -172,32 +190,37 @@ data = n.ma.array(data, mask=mask)
 map.imshow(data, vmax=max, vmin=min, cmap=cmap)
 
 # Plot src labels and markers on top of map image
-if not opts.srcs is None:
+if not opts.src is None:
     sx, sy = map(slons,slats)
     for name, xpt, ypt, flx in zip(snams, sx, sy, sflxs):
         if xpt >= 1e30 or ypt >= 1e30: continue
         if opts.src_mark != '':
             map.plot(sx, sy, opts.src_color+opts.src_mark,markerfacecolor=None)
+        if flx < 10: flx = 10
         p.text(xpt+.001, ypt+.001, name, size=5+2*int(n.round(n.log10(flx))),
             color=opts.src_color)
 if not opts.nobar: p.colorbar(shrink=.5, format='%.2f')
 else: p.subplots_adjust(.05,.05,.95,.95)
 
-# Add right-click functionality for finding locations/strengths in map.
-cnt = 1
-def click(event):
-    global cnt
-    if event.button != 3: return
-    lon,lat = map(event.xdata, event.ydata, inverse=True)
-    if opts.osys == 'eq': lon = (360 - lon) % 360
-    lon *= a.img.deg2rad; lat *= a.img.deg2rad
-    ra,dec = ephem.hours(lon), ephem.degrees(lat)
-    x,y,z = a.coord.radec2eq((ra,dec))
-    flx = h[(x,y,z)]
-    print '#%d (RA,DEC): (%s, %s), Jy: %f' % (cnt, ra, dec, flx)
-    cnt += 1
+if opts.outfile != '':
+    print 'Saving to', opts.outfile
+    p.savefig(opts.outfile)
+else:
+    # Add right-click functionality for finding locations/strengths in map.
+    cnt = 1
+    def click(event):
+        global cnt
+        if event.button != 3: return
+        lon,lat = map(event.xdata, event.ydata, inverse=True)
+        if opts.osys == 'eq': lon = (360 - lon) % 360
+        lon *= a.img.deg2rad; lat *= a.img.deg2rad
+        ra,dec = ephem.hours(lon), ephem.degrees(lat)
+        x,y,z = a.coord.radec2eq((ra,dec))
+        flx = h[(x,y,z)]
+        print '#%d (RA,DEC): (%s, %s), Jy: %f' % (cnt, ra, dec, flx)
+        cnt += 1
 
-#register this function with the event handler
-p.connect('button_press_event', click)
+    #register this function with the event handler
+    p.connect('button_press_event', click)
 
-p.show()
+    p.show()
