@@ -2,8 +2,7 @@
 Module for reading and setting parameters in components of an AntennaArray
 simulation for purpose of fitting.
 """
-import ant, sim, numpy as n
-from interp import interpolate
+import amp, numpy as n
 
 #  _   _ _   _ _ _ _           _____                 _   _                 
 # | | | | |_(_) (_) |_ _   _  |  ___|   _ _ __   ___| |_(_) ___  _ __  ___ 
@@ -12,11 +11,12 @@ from interp import interpolate
 #  \___/ \__|_|_|_|\__|\__, | |_|   \__,_|_| |_|\___|\__|_|\___/|_| |_|___/
 #                      |___/        
 
-def flatten_prms(prms, prm_list=[]):
+def flatten_prms(prms, prm_list=None):
     """Generate list of parameters suitable for passing to fitting
     algorithm from heirarchical parameter dictionary 'prms', along
     with 'key_list' information for reconstructing such a dictionary from
     a list.  'prm_list' is only for recursion."""
+    if prm_list is None: prm_list = []
     key_list = {}
     keys = prms.keys()
     keys.sort()
@@ -86,21 +86,21 @@ def print_params(prms, indent='', grad=None):
 # |_| \_\__,_|\__,_|_|\___/|_|   |_/_/\_\___|\__,_|____/ \___/ \__,_|\__, |
 #                                                                    |___/ 
 
-class RadioFixedBody(sim.RadioFixedBody):
+class RadioFixedBody(amp.RadioFixedBody):
     """Class representing a source at fixed RA,DEC.  Adds get_params() and
-    set_params() to sim.RadioFixedBody."""
-    def get_params(self, prm_list=None):
+    set_params() to amp.RadioFixedBody."""
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         aprms = {
-            'str':      list(self._janskies),
-            'index':    list(self._index),
+            'jys':      float(self._jys),
+            'index':    float(self.index),
             'ra':       float(self._ra),
             'dec':      float(self._dec),
-            'a1':  float(self.srcshape[0]),
-            'a2':  float(self.srcshape[1]),
-            'th':  float(self.srcshape[2]),
-            'dra':  float(self.ionref[0]),
-            'ddec':  float(self.ionref[1]),
+            'a1':       float(self.srcshape[0]),
+            'a2':       float(self.srcshape[1]),
+            'th':       float(self.srcshape[2]),
+            'dra':      float(self.ionref[0]),
+            'ddec':     float(self.ionref[1]),
         }
         prms = {}
         for p in prm_list:
@@ -110,16 +110,10 @@ class RadioFixedBody(sim.RadioFixedBody):
         return prms
     def set_params(self, prms):
         """Set all parameters from a dictionary."""
-        if prms.has_key('str'):
-            try:
-                len(prms['str'])
-                self._janskies = prms['str']
-            except: self._janskies = [prms['str']]
-        if prms.has_key('index'):
-            try:
-                len(prms['index'])
-                self._index = prms['index']
-            except: self._index = [prms['index']]
+        try: self._jys = prms['jys']
+        except(KeyError): pass
+        try: self.index = prms['index']
+        except(KeyError): pass
         try: self._ra = prms['ra']
         except(KeyError): pass
         try: self._dec = prms['dec']
@@ -142,19 +136,19 @@ class RadioFixedBody(sim.RadioFixedBody):
 # |_| \_\__,_|\__,_|_|\___/____/| .__/ \___|\___|_|\__,_|_|
 #                               |_|                        
 
-class RadioSpecial(sim.RadioSpecial):
+class RadioSpecial(amp.RadioSpecial):
     """Class representing moving sources (Sun,Moon,planets). Adds get_params() 
-    and set_params() to sim.RadioSpecial."""
-    def get_params(self, prm_list=None):
+    and set_params() to amp.RadioSpecial."""
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         aprms = {
-            'str':      list(self._janskies),
-            'index':    list(self._index),
+            'jys':      float(self._jys),
+            'index':    float(self.index),
             'a1':       float(self.srcshape[0]),
             'a2':       float(self.srcshape[1]),
             'th':       float(self.srcshape[2]),
-            'dra':  float(self.ionref[0]),
-            'ddec':  float(self.ionref[1]),
+            'dra':      float(self.ionref[0]),
+            'ddec':     float(self.ionref[1]),
         }
         prms = {}
         for p in prm_list:
@@ -164,16 +158,10 @@ class RadioSpecial(sim.RadioSpecial):
         return prms
     def set_params(self, prms):
         """Set all parameters from a dictionary."""
-        if prms.has_key('str'):
-            try:
-                len(prms['str'])
-                self._janskies = prms['str']
-            except: self._janskies = [prms['str']]
-        if prms.has_key('index'):
-            try:
-                len(prms['index'])
-                self._index = prms['index']
-            except: self._index = [prms['index']]
+        try: self._jys = prms['jys']
+        except(KeyError): pass
+        try: self.index = prms['index']
+        except(KeyError): pass
         try: self.srcshape[0] = prms['a1']
         except(KeyError): pass
         try: self.srcshape[1] = prms['a2']
@@ -192,9 +180,9 @@ class RadioSpecial(sim.RadioSpecial):
 # |____/|_|  \___|\____\__,_|\__\__,_|_|\___/ \__, |
 #                                             |___/ 
 
-class SrcCatalog(sim.SrcCatalog):
+class SrcCatalog(amp.SrcCatalog):
     """Class for holding a catalog of celestial sources.  Adds get_params()
-    and set_params() to sim.SrcCatalog."""
+    and set_params() to amp.SrcCatalog."""
     def get_params(self, src_prms={'*':'*'}):
         """Return all fitable parameters in a dictionary."""
         prms = {}
@@ -219,17 +207,17 @@ class SrcCatalog(sim.SrcCatalog):
 # | |_) |  __/ (_| | | | | | |
 # |____/ \___|\__,_|_| |_| |_|
 
-class BeamFlat(sim.BeamFlat):
+class Beam(amp.Beam):
     """Representation of a flat (gain=1) antenna beam pattern."""
-    def get_params(self, prm_list=None):
+    def get_params(self, prm_list=['*']):
         return {}
     def set_params(self, prms):
         pass
 
-class Beam2DGaussian(sim.Beam2DGaussian):
+class Beam2DGaussian(amp.Beam2DGaussian):
     """Representation of a 2D Gaussian beam pattern, with default setting for 
     a flat beam."""
-    def get_params(self, prm_list=None):
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         aprms = {'bm_xwidth':self.xwidth, 'bm_ywidth':self.ywidth}
         prms = {}
@@ -240,17 +228,16 @@ class Beam2DGaussian(sim.Beam2DGaussian):
         return prms
     def set_params(self, prms):
         """Set all parameters from a dictionary."""
-        xwidth, ywidth = None, None
-        try: xwidth = prms['bm_xwidth']
+        try: self.xwidth = prms['bm_xwidth']
         except(KeyError): pass
-        try: ywidth = prms['bm_ywidth']
+        try: self.ywidth = prms['bm_ywidth']
         except(KeyError): pass
-        self.update(xwidth, ywidth)
+        self.update()
 
-class BeamPolynomial(sim.BeamPolynomial):
+class BeamPolynomial(amp.BeamPolynomial):
     """Representation of a gaussian beam model whose width varies with azimuth
     angle and with frequency."""
-    def get_params(self, prm_list=None):
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         aprms = {'bm_poly':self.poly.flatten()}
         prms = {}
@@ -261,14 +248,18 @@ class BeamPolynomial(sim.BeamPolynomial):
         return prms
     def set_params(self, prms):
         """Set all parameters from a dictionary."""
-        try: self.update(prms['bm_poly'])
+        try: 
+            poly_azfreq = prms['bm_poly']
+            poly_azfreq.shape = self.poly.shape
+            self.poly = poly_azfreq
         except(KeyError): pass
+        self.update()
 
-class BeamAlm(sim.BeamAlm):
+class BeamAlm(amp.BeamAlm):
     """Representation of a beam model where each pointing has a response
     defined as a polynomial in frequency, and the spatial distributions of 
     these coefficients decomposed into spherical harmonics."""
-    def get_params(self, prm_list=[]):
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         aprms = {}
         for i, a in enumerate(self.alm):
@@ -286,10 +277,11 @@ class BeamAlm(sim.BeamAlm):
         for p in prms:
             if not p.startswith('alm'): continue
             data = n.array(prms[p])
-            p = int(p[3:])
+            c = int(p[3:])
             data.shape = (data.size/2, 2)
             data = data[:,0] + data[:,1] * 1j
-            self.update(coeffs={p:data})
+            if c < len(self.alm): self.alm[-1-c].set_data(data)
+        self.update()
 
 #     _          _                         
 #    / \   _ __ | |_ ___ _ __  _ __   __ _ 
@@ -297,13 +289,14 @@ class BeamAlm(sim.BeamAlm):
 #  / ___ \| | | | ||  __/ | | | | | | (_| |
 # /_/   \_\_| |_|\__\___|_| |_|_| |_|\__,_|
 
-class Antenna(sim.Antenna):
+class Antenna(amp.Antenna):
     """Representation of physical location and beam pattern of individual 
-    antenna in array.  Adds get_params() and set_params() to sim.Antenna."""
-    def get_params(self, prm_list=None):
+    antenna in array.  Adds get_params() and set_params() to amp.Antenna."""
+    def get_params(self, prm_list=['*']):
         """Return all fitable parameters in a dictionary."""
         x,y,z = self.pos
-        aprms = {'x':x, 'y':y, 'z':z, 'dly':self.delay, 'off':self._offset}
+        aprms = {'x':x, 'y':y, 'z':z, 'dly':self._phsoff[-2], 
+            'off':self._phsoff[-1], 'phsoff':self._phsoff}
         aprms['bp_r'] = list(self.bp_r)
         aprms['bp_i'] = list(self.bp_i)
         aprms['amp'] = self.amp
@@ -323,17 +316,19 @@ class Antenna(sim.Antenna):
         except(KeyError): pass
         try: self.pos[2] = prms['z']
         except(KeyError): pass
-        try: self.delay = prms['dly']
+        try: self._phsoff[-2] = prms['dly']
         except(KeyError): pass
-        try:
-            self._offset = prms['off']
-            try:
-                len(prms['off'])
-                self.offset = n.polyval(prms['off'], self.beam.afreqs)
-            except(AttributeError,TypeError): self.offset = (prms['off'] % 1)
+        try: self._phsoff[-1] = prms['off']
         except(KeyError): pass
-        self.update_gain(bp_r=prms.get('bp_r', None),
-            bp_i=prms.get('bp_i', None), amp=prms.get('amp', None))
+        try: self._phsoff = prms['phsoff']
+        except(KeyError): pass
+        try: self.bp_r = prms['bp_r']
+        except(KeyError): pass
+        try: self.bp_i = prms['bp_i']
+        except(KeyError): pass
+        try: self.amp = prms['amp']
+        except(KeyError): pass
+        self.update()
 
 #     _          _                            _                         
 #    / \   _ __ | |_ ___ _ __  _ __   __ _   / \   _ __ _ __ __ _ _   _ 
@@ -342,26 +337,25 @@ class Antenna(sim.Antenna):
 # /_/   \_\_| |_|\__\___|_| |_|_| |_|\__,_/_/   \_\_|  |_|  \__,_|\__, |
 #                                                                 |___/ 
 
-class AntennaArray(sim.AntennaArray):
+class AntennaArray(amp.AntennaArray):
     """Representation of location and time of observation, and response of
     array of antennas as function of pointing and frequency.  Adds get_params()
-    and set_params() to sim.AntennaArray."""
+    and set_params() to amp.AntennaArray."""
     def get_params(self, ant_prms={'*':'*'}):
         """Return all fitable parameters in a dictionary."""
         prms = {}
         for k in ant_prms:
-            if type(k) is str:
-                if k.startswith('*'): ants = range(len(self.ants))
-                else: continue
+            if k.startswith('*'): ants = map(str, range(len(self)))
             else: ants = [k]
             prm_list = ant_prms[k]
             if type(prm_list) is str: prm_list = [prm_list]
-            for a in ants: prms[a] = self.ants[a].get_params(prm_list)
+            for a in ants:
+                try: prms[a] = self.ants[int(a)].get_params(prm_list)
+                except(ValueError): pass
         return prms
     def set_params(self, prms):
         """Set all parameters from a dictionary."""
-        for i, a in enumerate(self.ants):
-            try: a.set_params(prms[i])
+        for i, a in enumerate(self):
+            try: a.set_params(prms[str(i)])
             except(KeyError): pass
-        self.update_antennas(self.ants)
-
+        self.update()
