@@ -3,25 +3,25 @@ Module containing utilities (like parsing of certain command-line arguments)
 for writing scripts.
 """
 
-import miriad, ant, sim, fit, src, numpy as n, re
+import miriad, fit, src, numpy as n, re
 
 def add_standard_options(optparser, ant=False, pol=False, chan=False, 
-        loc=False, loc2=False, src=False, dec=False, cmap=False, max=False,
-        drng=False):
+        cal=False, src=False, prms=False, dec=False, cmap=False, 
+        max=False, drng=False):
     """Add standard command-line options to an optparse.OptionParser() on an 
     opt in basis (i.e. specify =True for each option to be added)."""
     if ant: optparser.add_option ('-a', '--ant', dest='ant', default='cross',
-         help='Select ants/baselines to include.  Examples: all (all baselines) auto (of active baselines, only i=j) cross (only i!=j) 0,1,2 (any baseline involving listed ants) 0_2,0_3 (only listed baselines) "(0,1)_(2,3)" (same as 0_2,0_3,1_2,2_3. Quates help bash deal with parentheses) "(-0,1)_(2,-3)" (exclude 0_2,0_3,1_3 include 1_2).')
+         help='Select ants/baselines to include.  Examples: all (all baselines) auto (of active baselines, only i=j) cross (only i!=j) 0,1,2 (any baseline involving listed ants) 0_2,0_3 (only listed baselines) "(0,1)_(2,3)" (same as 0_2,0_3,1_2,2_3. Quotes help bash deal with parentheses) "(-0,1)_(2,-3)" (exclude 0_2,0_3,1_3 include 1_2).  Default is "cross".')
     if pol: optparser.add_option('-p', '--pol', dest='pol', 
         help='Choose polarization (xx, yy, xy, yx) to include.')
     if chan: optparser.add_option('-c', '--chan', dest='chan', default='all',
-        help='Select channels (taken after any delay/fringe transforms) to include.  Options are "all", "<chan1 #>,..." (a list of channels), or "<chan1 #>_<chan2 #>" (a range of channels).  Default is "all".')
-    if loc: optparser.add_option('-l', '--loc', dest='loc', 
-        help='Use specified <loc>.py for location-specific calibration.')
-    elif loc2: optparser.add_option('-l', '--loc', dest='loc', action='append',
-        help='Use specified <loc>.py for location-specific calibration.  Can intersperse locations with UV files to use different calibrations for different files.')
+        help='Select channels (after any delay/delay-rate transforms) to include.  Examples: all (all channels), 0_10 (channels from 0 to 10, including 0 and 10) 0_10_2 (channels from 0 to 10, counting by 2), 0,10,20_30 (mix of individual channels and ranges).  Default is "all".')
+    if cal: optparser.add_option('-C', '--cal', dest='cal', 
+        help='Use specified <cal>.py for calibration information.')
     if src: optparser.add_option('-s', '--src', dest='src',
         help='Phase centers/source catalog entries to use.  Options are "all", "<src_name1>,...", or "<ra XX[:XX:xx]>_<dec XX[:XX:xx]>".')
+    if prms: optparser.add_option('-P', '--prms', dest='prms',
+        help='Parameters (for fitting, usually), can be specified as can be: "obj=prm", "obj=prm/val", "obj=prm/val/sig", "(obj1/obj2)=prm/(val1/val2)/sig", "obj=(prm1/prm2)/val/(sig1/sig2)", comma separated versions of the above, and so on.')
     if dec:
         optparser.add_option('-x', '--decimate', dest='decimate', 
             default=1, type='int',
@@ -37,11 +37,6 @@ def add_standard_options(optparser, ant=False, pol=False, chan=False,
         optparser.add_option('--drng', dest='drng', type='float', default=None,
     help="Dynamic range in color of image, in units matching plotting mode.  Default max(data)-min(data).")
 
-def _strarg_to_range(strarg):
-    """Split command-line lists/ranges into a list of numbers."""
-    strarg = strarg.split(',')
-    return [map(float, option.split('_')) for option in strarg]
-
 ant_re = r'(\(((-?\d+,?)+)\)|-?\d+)'
 bl_re = '(^(%s_%s|%s),?)' % (ant_re, ant_re, ant_re)
 def parse_ants(ant_str, nants):
@@ -93,25 +88,30 @@ def uv_selector(uv, ants, pol_str):
     except(KeyError): raise ValueError('--pol argument invalid or absent')
     uv.select('polarization', polopt, 0)
 
-def parse_chans(chan_str, nchan):
+def parse_chans(chan_str, nchan, concat=True):
     """Return array of active channels based on number of channels and
-    string argument for chans (can be 'all', '20_30', or '55,56,57')."""
-    if chan_str.startswith('all'): chans = n.arange(nchan)
+    string argument for chans (all, 20_30, or 55,56,57, or 20_30,31,32).
+    Channel ranges include endpoints (i.e. 20_30 includes both 20 and 30)."""
+    if chan_str.startswith('all'): chanopt = [n.arange(nchan)]
     else:
-        chanopt = _strarg_to_range(chan_str)
-        if len(chanopt[0]) != 1:
-            chanopt = [n.arange(x,y, dtype=n.int) for x,y in chanopt]
-        chans = n.concatenate(chanopt)
-    return chans.astype(n.int)
+        chanopt = []
+        for co in chan_str.split(','):
+            co = map(int, co.split('_'))
+            assert(len(co) in [1,2,3])
+            if len(co) == 1: chanopt.append(n.array(co))
+            elif len(co) == 2: chanopt.append(n.arange(co[0],co[1]+1))
+            else: chanopt.append(n.arange(co[0],co[1]+1,co[2]))
+    if concat: return n.concatenate(chanopt)
+    return chanopt
 
 def parse_srcs(src_str):
     """Return (src_list,flux_cutoff) based on string argument for src.
-    Can be "all", "<src_name1>,...", or "<ra XX[:XX:xx]>_<dec XX[:XX:xx]>"."""
+    Can be "all", "<src_name1>,...", "<ra XX[:XX:xx]>_<dec XX[:XX:xx]>", or
+    "val/freq" (sources with Jy flux density above val at freq in GHz)."""
     if src_str.startswith('all'): return None, None
-    try:
-        cutoff = float(src_str)
+    if src_str.find('/') != -1:
+        cutoff = map(float, src_str.split('/'))
         return None, cutoff
-    except(ValueError): pass
     src_opt = src_str.split(',')
     if len(src_opt) == 1:
         src_opt = src_opt[0].split('_')
@@ -122,20 +122,55 @@ def parse_srcs(src_str):
     else:
         return src_opt, None
 
-def files_to_locs(locations, uvfiles, sysargv):
-    import optparse
-    o = optparse.OptionParser(); add_standard_options(o, loc2=True)
-    locs = {}
-    pos = [sysargv.index(uv) for uv in uvfiles]
-    curloc = locations[0]
-    for i in range(len(pos)):
-        locs[curloc] = locs.get(curloc, []) + [sysargv[pos[i]]]
-        if i < len(pos)-1 and pos[i+1] - pos[i] > 1:
-            opts,args = o.parse_args(sysargv[pos[i]+1:pos[i+1]])
-            if not opts.loc is None:
-                if curloc is None:
-                    locs[opts.loc[-1]] = locs[None]
-                    del(locs[None])
-                curloc = opts.loc[-1]
-    return locs
+name = r'([^\(/,\)=]+)'
+grp = r'(%s|\((%s(/%s)*)\))' % tuple([name]*3)
+prm = r'(%s=%s(/(%s)?(/%s)?)?)' % tuple([grp]*4)
+prm_rgx = re.compile(prm)
+def parse_prms(prm_str):
+    """Return a dict of the form: {'obj': {'prm':(val,sig),...}...} where
+    val is a starting value and sig is a known error associated with that 
+    start value.  Both default to None if a value is not provided.  The
+    string to be parsed can be: "obj=prm", "obj=prm/val", 
+    "obj=prm/val/sig", "(obj1/obj2)=prm/(val1/val2)/sig", 
+    "obj=(prm1/prm2)/val/(sig1/sig2)", comma separated versions of the above,
+    and so on."""
+    prms = {}
+    for prm in prm_str.split(','):
+        m = prm_rgx.match(prm)
+        g = m.groups()
+        if g[2]: obj = [g[2]]
+        else: obj = g[3].split('/')
+        if g[8]: plist = [g[8]]
+        else: plist = g[9].split('/')
+        if g[16]: ival = [float(g[16])]
+        elif g[17]: ival = map(float, g[17].split('/'))
+        else: ival = [None]
+        if g[23]: sval = [float(g[23])]
+        elif g[24]: sval = map(float, g[24].split('/'))
+        else: sval = [None]
+        if len(obj) != 1:
+            if len(plist) != 1:
+                assert(len(ival) == 1 and len(sval) == 1)
+                ival = [ival * len(plist)] * len(obj)
+                sval = [sval * len(plist)] * len(obj)
+            else:
+                if len(ival) == 1: ival = ival * len(obj)
+                if len(sval) == 1: sval = sval * len(obj)
+                assert(len(ival) == len(obj) and len(sval) == len(obj))
+                ival = [[i] for i in ival]
+                sval = [[i] for i in sval]
+        else:
+            if len(plist) != 1:
+                if len(ival) == 1: ival = ival * len(plist)
+                if len(sval) == 1: sval = sval * len(plist)
+                assert(len(ival) == len(plist) and len(sval) == len(plist))
+            else:
+                assert(len(ival) == 1 and len(sval) == 1)
+            ival = [ival]
+            sval = [sval]
+        for o,il,sl in zip(obj,ival,sval):
+            if not prms.has_key(o): prms[o] = {}
+            for p,i,s in zip(plist,il,sl):
+                prms[o][p] = (i,s)
+    return prms
 
